from setuptools import setup, find_packages

setup(
    author='Harish Daga',
    description='A module for mysql to get some basic details of database and tables like table ddl and row cound and space usage.',
    name='mysqlmastermanish',
    packages=find_packages(include=['mysqlmastermanish', 'musqlmastermanish.*']),
    install_requires=[
        'boto3==1.34.154',
        'botocore==1.34.154',
        'certifi==2024.7.4',
        'charset-normalizer==3.3.2',
        'docutils==0.21.2',
        'idna==3.7',
        'importlib_metadata==8.2.0',
        'jaraco.classes==3.4.0',
        'jaraco.context==5.3.0',
        'jaraco.functools==4.0.2',
        'jmespath==1.0.1',
        'keyring==25.3.0',
        'markdown-it-py==3.0.0',
        'mdurl==0.1.2',
        'more-itertools==10.3.0',
        'mysql-connector-python==9.0.0',
        'nh3==0.2.18',
        'numpy==2.0.1',
        'pandas==2.2.2',
        'pkginfo==1.10.0',
        'Pygments==2.18.0',
        'Pyment==0.3.3',
        'python-dateutil==2.9.0.post0',
        'pytz==2024.1',
        'readme_renderer==44.0',
        'requests==2.32.3',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.7.1',
        's3transfer==0.10.2',
        'setuptools==72.1.0',
        'six==1.16.0',
        'twine==5.1.1',
        'tzdata==2024.1',
        'urllib3==2.2.2',
        'zipp==3.19.2'
        ],
    python_requires='>=3.6',
    version='0.0.2'
)